@@ -20,6 +20,7 @@
 import refpolicy
 import access
 import re
+import sys
 
 # Convenience functions
 
@@ -37,8 +38,7 @@ def get_audit_boot_msgs():
     off=float(fd.read().split()[0])
     fd.close
     s = time.localtime(time.time() - off)
-    date = time.strftime("%D/%Y", s).split("/")
-    bootdate="%s/%s/%s" % (date[0], date[1], date[3])
+    bootdate = time.strftime("%x", s)
     boottime = time.strftime("%X", s)
     output = subprocess.Popen(["/sbin/ausearch", "-m", "AVC,USER_AVC,MAC_POLICY_LOAD,DAEMON_START,SELINUX_ERR", "-ts", bootdate, boottime],
                               stdout=subprocess.PIPE).communicate()[0]
@@ -172,7 +172,6 @@ class AVCMessage(AuditMessage):
         self.accesses = []
         self.denial = True
         self.type = audit2why.TERULE
-        self.bools = []
 
     def __parse_access(self, recs, start):
         # This is kind of sucky - the access that is in a space separated
@@ -240,10 +239,12 @@ class AVCMessage(AuditMessage):
         tcontext = self.tcontext.to_string()
         scontext = self.scontext.to_string()
         access_tuple = tuple( self.accesses)
+        self.data = []
+
         if (scontext, tcontext, self.tclass, access_tuple) in avcdict.keys():
-            self.type, self.bools = avcdict[(scontext, tcontext, self.tclass, access_tuple)]
+            self.type, self.data = avcdict[(scontext, tcontext, self.tclass, access_tuple)]
         else:
-            self.type, self.bools = audit2why.analyze(scontext, tcontext, self.tclass, self.accesses);
+            self.type, self.data = audit2why.analyze(scontext, tcontext, self.tclass, self.accesses);
             if self.type == audit2why.NOPOLICY:
                 self.type = audit2why.TERULE
             if self.type == audit2why.BADTCON:
@@ -257,7 +258,16 @@ class AVCMessage(AuditMessage):
             if self.type == audit2why.BADCOMPUTE:
                 raise ValueError("Error during access vector computation")
 
-            avcdict[(scontext, tcontext, self.tclass, access_tuple)] = (self.type, self.bools)
+            if self.type == audit2why.CONSTRAINT:
+                self.data = [ self.data ]
+                if self.scontext.user != self.tcontext.user:
+                    self.data.append(("user (%s)" % self.scontext.user, 'user (%s)' % self.tcontext.user))
+                if self.scontext.role != self.tcontext.role and self.tcontext.role != "object_r":
+                    self.data.append(("role (%s)" % self.scontext.role, 'role (%s)' % self.tcontext.role))
+                if self.scontext.level != self.tcontext.level:
+                    self.data.append(("level (%s)" % self.scontext.level, 'level (%s)' % self.tcontext.level))
+
+            avcdict[(scontext, tcontext, self.tclass, access_tuple)] = (self.type, self.data)
 
 class PolicyLoadMessage(AuditMessage):
     """Audit message indicating that the policy was reloaded."""
@@ -343,6 +353,7 @@ class AuditParser:
         self.policy_load_msgs = []
         self.path_msgs = []
         self.by_header = { }
+        self.check_input_file = False
                 
     # Low-level parsing function - tries to determine if this audit
     # message is an SELinux related message and then parses it into
@@ -378,6 +389,7 @@ class AuditParser:
                 found = True
                 
             if found:
+                self.check_input_file = True
                 try:
                     msg.from_split_string(rec)
                 except ValueError:
@@ -447,6 +459,9 @@ class AuditParser:
         while line:
             self.__parse(line)
             line = input.readline()
+        if not self.check_input_file:
+            sys.stderr.write("Nothing to do\n")
+            sys.exit(0)
         self.__post_process()
 
     def parse_string(self, input):
@@ -501,10 +516,10 @@ class AuditParser:
             if avc_filter:
                 if avc_filter.filter(avc):
                     av_set.add(avc.scontext.type, avc.tcontext.type, avc.tclass,
-                               avc.accesses, avc, avc_type=avc.type, bools=avc.bools)
+                               avc.accesses, avc, avc_type=avc.type, data=avc.data)
             else:
                 av_set.add(avc.scontext.type, avc.tcontext.type, avc.tclass,
-                           avc.accesses, avc, avc_type=avc.type, bools=avc.bools)
+                           avc.accesses, avc, avc_type=avc.type, data=avc.data)
         return av_set
 
 class AVCTypeFilter:
